#!/usr/bin/env bash

if [ "$1" = "-h" ]; then
        echo "Usage: start-shield-ca.sh <genkey> where genkey should be set to true only the first time and empty thereafter"
	exit 0
fi

######## Update these values #########

# Org Name (available from the Banyan Command Center under Settings)
ORG_NAME=<organization name>

# Org ID (available from the Banyan Command Center under Settings)
ORG_ID=<organization id>

# Examples: kubernetes, marathon, docker, ecs, none
CM=<cm type>

# If k8s, this needs to match the cluster of interest from kubeconfig
CNAME=<cluster name>

# Using default as prod
BANYAN_URL=https://net.banyanops.com:443/api_server_host_v1

# If using marathon, set to true: marathon nodes use a custom version of openssl that seems to be causing problems
TLSNOVERIFY=<true/false>

# Examples: stage, prod, test
GROUPTYPE=<type of deployment>

# Values: no, unless-stopped
RESTARTPOLICY=<policy if shield/CA exits>

# Config file in json format (only needed for AWS for now)
CONFIGFILE=config.json

# localhost port for banyan-ca
LOCALPORT=8888

# log directory
LOGDIR=$HOME/.banyan

# Enable scep or not: true, false
ENABLESCEP=false

# require all netagents to securely bootstrap their communication to shield: true, false
SECURE_BOOTSTRAP=false

# Optional value. In order to use Secure Bootstrap this should be used
# Public Addr of shield
# shield will be listening on port 1200 normally.
# <10.128.0.15:1200> or <myshield.example.corp.com:1200>
PUBLIC_ADDR=

######## UNTIL HERE #########


# Deploy Intermediate CA
GENKEY=$1
if [ "$GENKEY" != "true" ]; then
	GENKEY="false"
fi

OCSP_URL=${BANYAN_URL}/ocsp

./deploy-ca.sh ${GENKEY} ${LOCALPORT} ${ENABLESCEP} ${RESTARTPOLICY} ${OCSP_URL} ${ORG_NAME}

# wait for things to stabilize
sleep 5

# Deploy shield
./deploy-shield.sh ${ORG_ID} ${CM} ${CNAME} ${BANYAN_URL} ${TLSNOVERIFY} ${GROUPTYPE} ${RESTARTPOLICY} ${CONFIGFILE} ${LOCALPORT} ${LOGDIR} ${ENABLESCEP} ${SECURE_BOOTSTRAP} ${PUBLIC_ADDR}
